@@ -994,7 +994,7 @@ def instance_is_ready(vpc, instance):
 
 
 def wait_for_instance(vpc, instance):
-    logger.debug('waiting for instance %s to be running', instance.id)
+    logger.info('waiting for instance %s to be running', instance.id)
     time.sleep(5)
     while instance.state == 'pending':
         instance.update()
@@ -1015,7 +1015,7 @@ def get_subnet_by_id(vpc, subnet_id):
 
 
 def wait_for_subnet(vpc, instance):
-    logger.debug('waiting for subnet %s to be available', instance.id)
+    logger.info('waiting for subnet %s to be available', instance.id)
     iid = instance.id
     while instance.state != 'available':
         try:
